==> certmanager-model-v1beta1-5.7.0-sources.jar: io/fabric8/certmanager/api/model/v1beta1/CertificateKeystores.java <==

package io.fabric8.certmanager.api.model.v1beta1;

import java.util.HashMap;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.Container;
import io.fabric8.kubernetes.api.model.ContainerPort;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.VolumeMount;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.ToString;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "jks",
    "pkcs12"
})
@JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = true, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(ObjectMeta.class),
    @BuildableReference(ObjectReference.class),
    @BuildableReference(LabelSelector.class),
    @BuildableReference(Container.class),
    @BuildableReference(EnvVar.class),
    @BuildableReference(ContainerPort.class),
    @BuildableReference(Volume.class),
    @BuildableReference(VolumeMount.class)
})
public class CertificateKeystores implements KubernetesResource
{

    @JsonProperty("jks")
    private JKSKeystore jks;
    @JsonProperty("pkcs12")
    private PKCS12Keystore pkcs12;
    @JsonIgnore
    private Map<String, Object> additionalProperties = new HashMap<String, Object>();

    /**
     * No args constructor for use in serialization
     * 
     */
    public CertificateKeystores() {
    }

    /**
     * 
     * @param jks
     * @param pkcs12
     */
    public CertificateKeystores(JKSKeystore jks, PKCS12Keystore pkcs12) {
        super();
        this.jks = jks;
        this.pkcs12 = pkcs12;
    }

    @JsonProperty("jks")
    public JKSKeystore getJks() {
        return jks;
    }

    @JsonProperty("jks")
    public void setJks(JKSKeystore jks) {
        this.jks = jks;
    }

    @JsonProperty("pkcs12")
    public PKCS12Keystore getPkcs12() {
        return pkcs12;
    }

    @JsonProperty("pkcs12")
    public void setPkcs12(PKCS12Keystore pkcs12) {
        this.pkcs12 = pkcs12;
    }

    @JsonAnyGetter
    public Map<String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(String name, Object value) {
        this.additionalProperties.put(name, value);
    }

}

==> certmanager-model-v1beta1-5.11.0-sources.jar: io/fabric8/certmanager/api/model/v1beta1/CertificateKeystores.java <==

package io.fabric8.certmanager.api.model.v1beta1;

import java.util.HashMap;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.Container;
import io.fabric8.kubernetes.api.model.ContainerPort;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.VolumeMount;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.Setter;
import lombok.ToString;
import lombok.experimental.Accessors;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "jks",
    "pkcs12"
})
@JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@ToString
@EqualsAndHashCode
@Setter
@Accessors(prefix = {
    "_",
    ""
})
@Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(ObjectMeta.class),
    @BuildableReference(ObjectReference.class),
    @BuildableReference(LabelSelector.class),
    @BuildableReference(Container.class),
    @BuildableReference(EnvVar.class),
    @BuildableReference(ContainerPort.class),
    @BuildableReference(Volume.class),
    @BuildableReference(VolumeMount.class)
})
public class CertificateKeystores implements KubernetesResource
{

    @JsonProperty("jks")
    private JKSKeystore jks;
    @JsonProperty("pkcs12")
    private PKCS12Keystore pkcs12;
    @JsonIgnore
    private Map<String, Object> additionalProperties = new HashMap<String, Object>();

    /**
     * No args constructor for use in serialization
     * 
     */
    public CertificateKeystores() {
    }

    /**
     * 
     * @param jks
     * @param pkcs12
     */
    public CertificateKeystores(JKSKeystore jks, PKCS12Keystore pkcs12) {
        super();
        this.jks = jks;
        this.pkcs12 = pkcs12;
    }

    @JsonProperty("jks")
    public JKSKeystore getJks() {
        return jks;
    }

    @JsonProperty("jks")
    public void setJks(JKSKeystore jks) {
        this.jks = jks;
    }

    @JsonProperty("pkcs12")
    public PKCS12Keystore getPkcs12() {
        return pkcs12;
    }

    @JsonProperty("pkcs12")
    public void setPkcs12(PKCS12Keystore pkcs12) {
        this.pkcs12 = pkcs12;
    }

    @JsonAnyGetter
    public Map<String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(String name, Object value) {
        this.additionalProperties.put(name, value);
    }

}
